/* Light (default) theme */

.highlight span.n {
  color: #222;
}

.highlight span.c {
  color: #3F4D91;
  font-style: italic;
}

.highlight span.err {
  border: 1px solid #DC322F;
}

.highlight span.k {
  color: #586E75;
}

.highlight span.o {
  color: #586E75;
}

.highlight span.cm {
  color: #3F4D91;
  font-style: italic;
}

.highlight span.cp {
  color: #586E75;
}

.highlight span.cpf {
  color: #93115C;
}

.highlight span.c1 {
  color: #3F4D91;
  font-style: italic;
}

.highlight span.cs {
  color: #3F4D91;
  font-style: italic;
}

.highlight span.gd {
  color: #990A1B;
}

.highlight span.ge {
  font-style: italic;
}

.highlight span.gr {
  color: #DC322F;
}

.highlight span.gh {
  color: #3F4D91;
  font-weight: bold;
}

.highlight span.gi {
  color: #859900;
}

.highlight span.go {
  color: #666;
}

.highlight span.gp {
  color: #666;
  font-weight: bold;
}

.highlight span.gs {
  font-weight: bold;
}

.highlight span.gu {
  color: #444;
  font-weight: bold;
}

.highlight span.gt {
  color: #268BD2;
}

.highlight span.kc {
  color: #586E75;
  font-weight: bold;
}

.highlight span.kd {
  color: #586E75;
  font-weight: bold;
}

.highlight span.kn {
  color: #586E75;
  font-weight: bold;
}

.highlight span.kp {
  color: #586E75;
}

.highlight span.kr {
  color: #586E75;
  font-weight: bold;
}

.highlight span.kt {
  color: #586E75;
}

.highlight span.m {
  color: #666;
}

.highlight span.s {
  color: #93115C;
}

.highlight span.na {
  color: #444;
}

.highlight span.nb {
  color: #3F4D91;
}

.highlight span.nc {
  color: #000;
}

.highlight span.no {
  color: #880;
}

.highlight span.nd {
  color: #A2F;
}

.highlight span.ni {
  color: #666;
  font-weight: bold;
}

.highlight span.ne {
  color: #D2413A;
  font-weight: bold;
}

.highlight span.nf {
  color: #000;
}

.highlight span.nl {
  color: #546E00;
}

.highlight span.nn {
  color: #444;
}

.highlight span.nt {
  color: #444;
}

.highlight span.nv {
  color: #222;
}

.highlight span.ow {
  color: #3F4D91;
}

.highlight span.w {
  color: #BBB;
}

.highlight span.mb {
  color: #93115C;
  font-weight: bold;
}

.highlight span.mf {
  color: #93115C;
}

.highlight span.mh {
  color: #93115C;
  font-weight: bold;
}

.highlight span.mi {
  color: #93115C;
}

.highlight span.mo {
  color: #93115C;
  font-weight: bold;
}

.highlight span.sb {
  color: #93115C;
}

.highlight span.sc {
  color: #93115C;
}

.highlight span.sd {
  color: #3F4D91;
  font-style: italic;
}

.highlight span.s2 {
  color: #93115C;
}

.highlight span.se {
  color: #93115C;
  font-weight: bold;
}

.highlight span.sh {
  color: #93115C;
}

.highlight span.si {
  color: #93115C;
  font-weight: bold;
}

.highlight span.sx {
  color: #93115C;
}

.highlight span.sr {
  color: #93115C;
  font-weight: bold;
}

.highlight span.s1 {
  color: #93115C;
}

.highlight span.ss {
  color: #444;
  font-weight: bold;
}

.highlight span.bp {
  color: #859900;
}

.highlight span.vc {
  color: #00629D;
}

.highlight span.vg {
  color: #00629D;
}

.highlight span.vi {
  color: #00629D;
}

.highlight span.il {
  color: #000;
}

.highlight span.p {
  color: #444;
}

/* Dark theme */
@media (prefers-color-scheme: dark) {
  .highlight span.n {
    color: #CCC;
  }

  .highlight span.c {
    color: #6C71C4;
    font-style: italic;
  }

  .highlight span.err {
    border: 1px solid #FF6E64;
  }

  .highlight span.k {
    color: #93A1A1;
  }

  .highlight span.o {
    color: #93A1A1;
  }

  .highlight span.cm {
    color: #6C71C4;
    font-style: italic;
  }

  .highlight span.cp {
    color: #93A1A1;
  }

  .highlight span.cpf {
    color: #D33682;
  }

  .highlight span.c1 {
    color: #6C71C4;
    font-style: italic;
  }

  .highlight span.cs {
    color: #6C71C4;
    font-style: italic;
  }

  .highlight span.gd {
    color: #DC322F;
  }

  .highlight span.ge {
    font-style: italic;
  }

  .highlight span.gr {
    color: #FF6E64;
  }

  .highlight span.gh {
    color: #6C71C4;
    font-weight: bold;
  }

  .highlight span.gi {
    color: #859900;
  }

  .highlight span.go {
    color: #666;
  }

  .highlight span.gp {
    color: #666;
    font-weight: bold;
  }

  .highlight span.gs {
    font-weight: bold;
  }

  .highlight span.gu {
    color: #BBB;
    font-weight: bold;
  }

  .highlight span.gt {
    color: #69B7F0;
  }

  .highlight span.kc {
    color: #93A1A1;
    font-weight: bold;
  }

  .highlight span.kd {
    color: #93A1A1;
    font-weight: bold;
  }

  .highlight span.kn {
    color: #93A1A1;
    font-weight: bold;
  }

  .highlight span.kp {
    color: #93A1A1;
  }

  .highlight span.kr {
    color: #93A1A1;
    font-weight: bold;
  }

  .highlight span.kt {
    color: #93A1A1;
  }

  .highlight span.m {
    color: #999;
  }

  .highlight span.s {
    color: #D33682;
  }

  .highlight span.na {
    color: #BBB;
  }

  .highlight span.nb {
    color: #6C71C4;
  }

  .highlight span.nc {
    color: #FFF;
  }

  .highlight span.no {
    color: #880;
  }

  .highlight span.nd {
    color: #A2F;
  }

  .highlight span.ni {
    color: #999;
    font-weight: bold;
  }

  .highlight span.ne {
    color: #D2413A;
    font-weight: bold;
  }

  .highlight span.nf {
    color: #FFF;
  }

  .highlight span.nl {
    color: #546E00;
  }

  .highlight span.nn {
    color: #BBB;
  }

  .highlight span.nt {
    color: #BBB;
  }

  .highlight span.nv {
    color: #DDD;
  }

  .highlight span.ow {
    color: #6C71C4;
  }

  .highlight span.w {
    color: #BBB;
  }

  .highlight span.mb {
    color: #D33682;
    font-weight: bold;
  }

  .highlight span.mf {
    color: #D33682;
  }

  .highlight span.mh {
    color: #D33682;
    font-weight: bold;
  }

  .highlight span.mi {
    color: #D33682;
  }

  .highlight span.mo {
    color: #D33682;
    font-weight: bold;
  }

  .highlight span.sb {
    color: #D33682;
  }

  .highlight span.sc {
    color: #D33682;
  }

  .highlight span.sd {
    color: #6C71C4;
    font-style: italic;
  }

  .highlight span.s2 {
    color: #D33682;
  }

  .highlight span.se {
    color: #D33682;
    font-weight: bold;
  }

  .highlight span.sh {
    color: #D33682;
  }

  .highlight span.si {
    color: #D33682;
    font-weight: bold;
  }

  .highlight span.sx {
    color: #D33682;
  }

  .highlight span.sr {
    color: #D33682;
    font-weight: bold;
  }

  .highlight span.s1 {
    color: #D33682;
  }

  .highlight span.ss {
    color: #BBB;
    font-weight: bold;
  }

  .highlight span.bp {
    color: #859900;
  }

  .highlight span.vc {
    color: #268BD2;
  }

  .highlight span.vg {
    color: #268BD2;
  }

  .highlight span.vi {
    color: #268BD2;
  }

  .highlight span.il {
    color: #FFF;
  }

  .highlight span.p {
    color: #BBB;
  }
}
